@@ -1,5 +1,5 @@
 # This file is part of nrpe-ng.
-# Copyright (C) 2014  Chris Boot <bootc@bootc.net>
+# Copyright (C) 2014-17  Chris Boot <bootc@bootc.net>
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -15,7 +15,8 @@
 # with this program; if not, write to the Free Software Foundation, Inc.,
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
-from .server import Server  # NoQA
-from .__main__ import main  # NoQA, for the setuptools entry point
+from .server import Server
 
-__all__ = locals()
+
+def main():
+    return Server().run()
