@@ -1,5 +1,5 @@
 # This file is part of nrpe-ng.
-# Copyright (C) 2014  Chris Boot <bootc@bootc.net>
+# Copyright (C) 2014-17  Chris Boot <bootc@bootc.net>
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -18,8 +18,5 @@
 from .server import Server
 
 
-def main():
-    return Server().run()
-
 if __name__ == "__main__":
-    main()
+    Server().run()
